@@ -1,7 +1,9 @@
 from __future__ import annotations
 
 import argparse
+import json
 import os
+import sys
 from argparse import Action, _ArgumentGroup
 from collections import ChainMap, OrderedDict
 from json import dumps
@@ -10,6 +12,7 @@ from typing import TYPE_CHECKING, Any, Callable, Iterable, Mapping, MutableMappi
 
 import atoml
 from packaging.specifiers import SpecifierSet
+from pip._vendor.pkg_resources import parse_version
 from resolvelib.structs import DirectedGraph
 
 from pdm import termui
@@ -17,6 +20,7 @@ from pdm._types import Distribution
 from pdm.exceptions import PdmUsageError, ProjectError
 from pdm.formats import FORMATS
 from pdm.formats.base import make_array, make_inline_table
+from pdm.models.pip_shims import url_to_path
 from pdm.models.requirements import (
     Requirement,
     filter_requirements_with_extras,
@@ -422,9 +426,7 @@ def format_dependency_graph(
 
 
 def format_lockfile(
-    mapping: dict[str, Candidate],
-    fetched_dependencies: dict[str, list[Requirement]],
-    summary_collection: dict[str, str],
+    mapping: dict[str, Candidate], fetched_dependencies: dict[str, list[Requirement]]
 ) -> dict:
     """Format lock file from a dict of resolved candidates, a mapping of dependencies
     and a collection of package summaries.
@@ -434,7 +436,7 @@ def format_lockfile(
     for k, v in sorted(mapping.items()):
         base = atoml.table()
         base.update(v.as_lockfile_entry())  # type: ignore
-        base.add("summary", summary_collection[strip_extras(k)[0]])
+        base.add("summary", v.summary)
         deps = make_array(sorted(r.as_line() for r in fetched_dependencies[k]), True)
         if len(deps) > 0:
             base.add("dependencies", deps)
@@ -475,8 +477,11 @@ def save_version_specifiers(
                     r.specifier = get_specifier(f"=={resolved[name].version}")
                 elif save_strategy == "compatible":
                     version = str(resolved[name].version)
-                    compatible_version = ".".join((version.split(".") + ["0"])[:2])
-                    r.specifier = get_specifier(f"~={compatible_version}")
+                    parsed = parse_version(version)
+                    if parsed.is_prerelease or parsed.is_devrelease:
+                        r.specifier = get_specifier(f">={version},<{parsed.major + 1}")
+                    else:
+                        r.specifier = get_specifier(f"~={parsed.major}.{parsed.minor}")
 
 
 def check_project_file(project: Project) -> None:
@@ -601,3 +606,34 @@ def frozen_requirement_from_dist(dist: Distribution) -> str:
     except StopIteration:
         raise TypeError(f"Not a valid distribution metadata: {dist_path}")
     return str(FrozenRequirement.from_dist(pkg_dist))
+
+
+def is_pipx_installation() -> bool:
+    return sys.prefix.split(os.sep)[-3:-1] == ["pipx", "venvs"]
+
+
+def is_homebrew_installation() -> bool:
+    return "/libexec" in sys.prefix.replace("\\", "/")
+
+
+def is_scoop_installation() -> bool:
+    if os.name != "nt":
+        return False
+    try:
+        Path(sys.prefix).relative_to(Path.home() / "scoop/apps/pdm")
+    except ValueError:
+        return False
+    return True
+
+
+def get_dist_location(dist: Distribution) -> str:
+    direct_url = dist.read_text("direct_url.json")
+    if not direct_url:
+        return ""
+    direct_url_data = json.loads(direct_url)
+    url = cast(str, direct_url_data["url"])
+    if url.startswith("file:"):
+        path = url_to_path(url)
+        editable = direct_url_data.get("dir_info", {}).get("editable", False)
+        return f"{'-e ' if editable else ''}{path}"
+    return ""
