@@ -5,6 +5,7 @@ import functools
 import os
 import re
 import secrets
+import sys
 import urllib.parse as urlparse
 import warnings
 from pathlib import Path
@@ -35,17 +36,24 @@ from pdm.utils import (
     url_without_fragments,
 )
 
+if sys.version_info >= (3, 8):
+    from importlib.metadata import Distribution
+else:
+    from importlib_metadata import Distribution
+
 VCS_SCHEMA = ("git", "hg", "svn", "bzr")
-VCS_REQ = re.compile(
-    rf"(?P<url>(?P<vcs>{'|'.join(VCS_SCHEMA)})\+[^\s;]+)(?P<marker>[\t ]*;[^\n]+)?"
+_vcs_req_re = re.compile(
+    rf"(?P<url>(?P<vcs>{'|'.join(VCS_SCHEMA)})\+[^\s;]+)(?P<marker>[\t ]*;[^\n]+)?",
+    flags=re.IGNORECASE,
 )
-FILE_REQ = re.compile(
+_file_req_re = re.compile(
     r"(?:(?P<url>\S+://[^\s\[\];]+)|"
     r"(?P<path>(?:[^\s;\[\]]|\\ )*"
     r"|'(?:[^']|\\')*'"
     r"|\"(?:[^\"]|\\\")*\"))"
     r"(?P<extras>\[[^\[\]]+\])?(?P<marker>[\t ]*;[^\n]+)?"
 )
+_egg_info_re = re.compile(r"([a-z0-9_.]+)-([a-z0-9_.!+-]+)", re.IGNORECASE)
 T = TypeVar("T", bound="Requirement")
 
 
@@ -156,11 +164,7 @@ class Requirement:
         for vcs in VCS_SCHEMA:
             if vcs in req_dict:
                 repo = cast(str, req_dict.pop(vcs, None))
-                url = (
-                    vcs
-                    + "+"
-                    + VcsRequirement._build_url_from_req_dict(name, repo, req_dict)
-                )
+                url = vcs + "+" + repo
                 return VcsRequirement.create(name=name, vcs=vcs, url=url, **req_dict)
         if "path" in req_dict or "url" in req_dict:
             return FileRequirement.create(name=name, **req_dict)
@@ -212,11 +216,11 @@ class Requirement:
             "marker": get_marker(req.marker),
         }
         if getattr(req, "url", None):
-            link = Link(req.url)
+            link = Link(cast(str, req.url))
             klass = VcsRequirement if link.is_vcs else FileRequirement
             return klass(url=req.url, **kwargs)  # type: ignore
         else:
-            return NamedRequirement(**kwargs)
+            return NamedRequirement(**kwargs)  # type: ignore
 
     def _format_marker(self) -> str:
         if self.marker:
@@ -238,6 +242,7 @@ class NamedRequirement(Requirement):
 class FileRequirement(Requirement):
     url: str = ""
     path: Path | None = None
+    subdirectory: str | None = None
 
     def __post_init__(self) -> None:
         super().__post_init__()
@@ -305,8 +310,11 @@ class FileRequirement(Requirement):
         extras = f"[{','.join(sorted(self.extras))}]" if self.extras else ""
         marker = self._format_marker()
         url = url_without_fragments(self.url)
-        if self.editable:
-            return f"-e {url}#egg={project_name}{extras}{marker}"
+        if self.editable or self.subdirectory:
+            fragments = f"egg={project_name}{extras}"
+            if self.subdirectory:
+                fragments = f"{fragments}&subdirectory={self.subdirectory}"
+            return f"{'-e ' if self.editable else ''}{url}#{fragments}{marker}"
         delimiter = " @ " if project_name else ""
         return f"{project_name}{extras}{delimiter}{url}{marker}"
 
@@ -322,6 +330,12 @@ class FileRequirement(Requirement):
             filename = os.path.basename(url_without_fragments(self.url))
             if filename.endswith(".whl"):
                 self.name, self.version = parse_name_version_from_wheel(filename)
+            else:
+                match = _egg_info_re.match(filename)
+                # Filename is like `<name>-<version>.tar.gz`, where name will be
+                # extracted and version will be left to be determined from the metadata.
+                if match:
+                    self.name = match.group(1)
 
     def _check_installable(self) -> None:
         assert self.path
@@ -348,30 +362,39 @@ class VcsRequirement(FileRequirement):
         if not self.vcs:
             self.vcs = self.url.split("+", 1)[0]
 
-    def as_ireq(self, **kwargs: Any) -> InstallRequirement:
-        ireq = super().as_ireq(**kwargs)
-        if not self.editable and self.revision:
-            # For non-editable VCS requirements, commit-hash should be used as the
-            # rev-options for InstallRequirement to consume.
-            parsed = urlparse.urlparse(cast(Link, ireq.link).url)
-            new_path = "@".join((parsed.path.split("@", 1)[0], self.revision))
-            new_url = urlparse.urlunparse(parsed._replace(path=new_path))
-            ireq.link = Link(new_url)
-        return ireq
+    def as_line(self) -> str:
+        project_name = f"{self.project_name}" if self.project_name else ""
+        extras = f"[{','.join(sorted(self.extras))}]" if self.extras else ""
+        marker = self._format_marker()
+        url = url_without_fragments(self.url)
+        if self.revision and not self.editable:
+            url += f"@{self.revision}"
+        elif self.ref:
+            url += f"@{self.ref}"
+        if self.editable or self.subdirectory:
+            fragments = f"egg={project_name}{extras}"
+            if self.subdirectory:
+                fragments = f"{fragments}&subdirectory={self.subdirectory}"
+            return f"{'-e ' if self.editable else ''}{url}#{fragments}{marker}"
+        delimiter = " @ " if project_name else ""
+        return f"{project_name}{extras}{delimiter}{url}{marker}"
 
     def _parse_url(self) -> None:
         vcs, url_no_vcs = self.url.split("+", 1)
         if url_no_vcs.startswith("git@"):
             url_no_vcs = add_ssh_scheme_to_git_uri(url_no_vcs)
-            self.url = f"{vcs}+{url_no_vcs}"
         if not self.name:
             self._parse_name_from_url()
-        repo = url_without_fragments(url_no_vcs)
-        ref: str | None = None
-        parsed = urlparse.urlparse(repo)
+        ref = self.ref
+        parsed = urlparse.urlparse(url_no_vcs)
+        path = parsed.path
+        fragments = dict(urlparse.parse_qsl(parsed.fragment))
+        if "subdirectory" in fragments:
+            self.subdirectory = fragments["subdirectory"]
         if "@" in parsed.path:
             path, ref = parsed.path.split("@", 1)
-            repo = urlparse.urlunparse(parsed._replace(path=path))
+        repo = urlparse.urlunparse(parsed._replace(path=path, fragment=""))
+        self.url = f"{vcs}+{repo}"
         self.repo, self.ref = repo, ref  # type: ignore
 
     @staticmethod
@@ -388,28 +411,21 @@ class VcsRequirement(FileRequirement):
 
 
 def filter_requirements_with_extras(
-    requirement_lines: list[str | dict[str, str | list[str]]],
+    requirement_lines: list[str],
     extras: Sequence[str],
 ) -> list[str]:
     result: list[str] = []
-    extras_in_meta = []
+    extras_in_meta: list[str] = []
     for req in requirement_lines:
-        if isinstance(req, dict):
-            if req.get("extra"):
-                extras_in_meta.append(req["extra"])
-            if not req.get("extra") or req.get("extra") in extras:
-                marker = f"; {req['environment']}" if req.get("environment") else ""
-                result.extend(f"{line}{marker}" for line in req.get("requires", []))
+        _r = parse_requirement(req)
+        if not _r.marker:
+            result.append(req)
         else:
-            _r = parse_requirement(req)
-            if not _r.marker:
-                result.append(req)
-            else:
-                elements, rest = split_marker_extras(_r.marker)
-                extras_in_meta.extend(elements)
-                _r.marker = rest
-                if not elements or set(extras) & set(elements):
-                    result.append(_r.as_line())
+            elements, rest = split_marker_extras(_r.marker)
+            extras_in_meta.extend(elements)
+            _r.marker = Marker(str(rest)) if rest else None
+            if not elements or set(extras) & set(elements):
+                result.append(_r.as_line())
 
     extras_not_found = [e for e in extras if e not in extras_in_meta]
     if extras_not_found:
@@ -420,7 +436,7 @@ def filter_requirements_with_extras(
 
 def parse_requirement(line: str, editable: bool = False) -> Requirement:
 
-    m = VCS_REQ.match(line)
+    m = _vcs_req_re.match(line)
     r: Requirement
     if m is not None:
         r = VcsRequirement.create(**m.groupdict())
@@ -428,7 +444,7 @@ def parse_requirement(line: str, editable: bool = False) -> Requirement:
         try:
             package_req = PackageRequirement(line)  # type: ignore
         except (RequirementParseError, InvalidRequirement) as e:
-            m = FILE_REQ.match(line)
+            m = _file_req_re.match(line)
             if m is None:
                 raise RequirementError(str(e)) from None
             r = FileRequirement.create(**m.groupdict())
@@ -445,3 +461,47 @@ def parse_requirement(line: str, editable: bool = False) -> Requirement:
                 " or local directory."
             )
     return r
+
+
+class MockDistribution(Distribution):
+    def __init__(self, data: Setup) -> None:
+        self._data = data
+
+    def read_text(self, filename: str) -> str | None:
+        return None
+
+    def locate_file(self, path: os.PathLike[str] | str) -> os.PathLike[str]:
+        return Path("")
+
+    @property
+    def metadata(self) -> dict[str, Any]:  # type: ignore
+        return {
+            "Name": self._data.name,
+            "Version": self._data.version,
+            "Summary": "UNKNOWN",
+            "Requires-Python": self._data.python_requires,
+        }
+
+    @property
+    def requires(self) -> list[str] | None:
+        result = self._data.install_requires
+        for extra, reqs in self._data.extras_require.items():
+            extra_marker = f"extra == '{extra}'"
+            for req in reqs:
+                parsed = parse_requirement(req)
+                old_marker = str(parsed.marker) if parsed.marker else None
+                if old_marker:
+                    if " or " in old_marker:
+                        new_marker = f"({old_marker}) and {extra_marker}"
+                    else:
+                        new_marker = f"{old_marker} and {extra_marker}"
+                else:
+                    new_marker = extra_marker
+                parsed.marker = Marker(new_marker)
+                result.append(parsed.as_line())
+        return result
+
+
+def parse_metadata_from_source(src_dir: str) -> Distribution:
+    setup = Setup.from_directory(Path(src_dir))
+    return MockDistribution(setup)
