@@ -141,6 +141,14 @@ def test_install_with_lockfile(project, invoke, working_set, repository):
     assert project.is_lockfile_hash_match()
 
 
+def test_install_with_dry_run(project, invoke, repository):
+    project.add_dependencies({"pytz": parse_requirement("pytz")}, "default")
+    result = invoke(["install", "--dry-run"], obj=project)
+    project._lockfile = None
+    assert "pytz" not in project.locked_repository.all_candidates
+    assert "pytz 2019.3" in result.output
+
+
 def test_init_command(project_no_init, invoke, mocker):
     mocker.patch(
         "pdm.cli.commands.init.get_user_email_from_git",
@@ -257,7 +265,7 @@ def test_config_env_var_shadowing(project, invoke):
         assert result.output.strip() == "https://example.org/simple"
 
         result = invoke(
-            ["config", "pypi.url", "https://testpypi.org/pypi"], obj=project
+            ["config", "pypi.url", "https://test.pypi.org/pypi"], obj=project
         )
         assert "config is shadowed by env var 'PDM_PYPI_URL'" in result.output
         result = invoke(["config", "pypi.url"], obj=project)
@@ -265,7 +273,7 @@ def test_config_env_var_shadowing(project, invoke):
 
         del os.environ["PDM_PYPI_URL"]
         result = invoke(["config", "pypi.url"], obj=project)
-        assert result.output.strip() == "https://testpypi.org/pypi"
+        assert result.output.strip() == "https://test.pypi.org/pypi"
 
 
 def test_config_project_global_precedence(project, invoke):
@@ -295,7 +303,7 @@ def test_import_requirement_no_overwrite(project, invoke, tmp_path):
     project.add_dependencies({"requests": parse_requirement("requests")})
     tmp_path.joinpath("reqs.txt").write_text("flask\nflask-login\n")
     result = invoke(
-        ["import", "-dsweb", str(tmp_path.joinpath("reqs.txt"))], obj=project
+        ["import", "-dGweb", str(tmp_path.joinpath("reqs.txt"))], obj=project
     )
     assert result.exit_code == 0, result.stderr
     assert list(project.get_dependencies()) == ["requests"]
@@ -372,3 +380,14 @@ def test_lock_legacy_project(invoke, fixture_project, repository):
     result = invoke(["lock"], obj=project)
     assert result.exit_code == 0
     assert "urllib3" in project.locked_repository.all_candidates
+
+
+def test_show_update_hint(invoke, project):
+    prev_version = project.core.version
+    try:
+        project.core.version = "0.0.0"
+        r = invoke(["config"], obj=project)
+    finally:
+        project.core.version = prev_version
+    assert "to upgrade." in r.stderr
+    assert "Run $ pdm config check_update false to disable the check." in r.stderr
