@@ -6,7 +6,7 @@ import shutil
 import sys
 from io import BytesIO
 from pathlib import Path
-from typing import Callable, Iterable, List, Tuple
+from typing import Callable, Dict, Iterable, List, Optional, Tuple
 from urllib.parse import urlparse
 
 import pytest
@@ -24,7 +24,7 @@ from pdm.models.repositories import BaseRepository
 from pdm.models.requirements import Requirement, filter_requirements_with_extras
 from pdm.project import Project
 from pdm.project.config import Config
-from pdm.utils import cached_property, get_finder, normalize_name, temp_environ
+from pdm.utils import get_finder, normalize_name, temp_environ
 from tests import FIXTURES
 
 os.environ["CI"] = "1"
@@ -51,6 +51,8 @@ class LocalFileAdapter(requests.adapters.BaseAdapter):
             response.status_code = 200
             response.reason = "OK"
             response.raw = file_path.open("rb")
+            if file_path.suffix == ".html":
+                response.headers["Content-Type"] = "text/html"
         self._opened_files.append(response.raw)
         return response
 
@@ -115,8 +117,8 @@ class TestRepository(BaseRepository):
             self._get_dependencies_from_metadata,
         )
 
-    def get_hashes(self, candidate: Candidate) -> None:
-        candidate.hashes = {}
+    def get_hashes(self, candidate: Candidate) -> Optional[Dict[str, str]]:
+        return {}
 
     def _find_candidates(self, requirement: Requirement) -> Iterable[Candidate]:
         for version, candidate in self._pypi_data.get(requirement.key, {}).items():
@@ -141,10 +143,6 @@ class TestProject(Project):
         self.GLOBAL_PROJECT = self.root_path / ".pdm-home" / "global-project"
         super().__init__(core, root_path, is_global)
 
-    @cached_property
-    def global_config(self):
-        return Config(self.root_path / ".pdm-home" / "config.toml", is_global=True)
-
 
 main.project_class = TestProject
 
@@ -167,6 +165,9 @@ class Distribution:
     def requires(self):
         return self.dependencies
 
+    def read_text(self, path):
+        return None
+
 
 class MockWorkingSet(collections.abc.MutableMapping):
     def __init__(self, *args, **kwargs):
@@ -279,7 +280,7 @@ def copytree(src: Path, dst: Path) -> None:
 
 @pytest.fixture()
 def fixture_project(project_no_init):
-    """Initailize a project from a fixture project"""
+    """Initialize a project from a fixture project"""
 
     def func(project_name):
         source = FIXTURES / "projects" / project_name
