@@ -19,6 +19,10 @@ from pdm.models.specifiers import PySpecSet
         (">=3.6,<3.8,!=3.8.*", ">=3.6,<3.8"),
         (">=2.7,<3.2,!=3.0.*,!=3.1.*", ">=2.7,<3.0"),
         ("!=3.0.*,!=3.0.2", "!=3.0.*"),
+        (">=3.4.*", ">=3.4"),
+        (">3.4.*", ">=3.5"),
+        ("<=3.4.*", "<3.4"),
+        ("<3.4.*", "<3.4"),
     ],
 )
 def test_normalize_pyspec(original, normalized):
